==> blesta-5.10.2.zip: blesta/components/modules/virtualmin/language/sv_se/virtualmin.php <==
<?php
/**
 * Virtualmin
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Virtualmin.!error.virtualmin_password.valid'] = 'Lösenordet måste vara minst 8 tecken långt.';
$lang['Virtualmin.!error.virtualmin_username.length'] = 'Användarnamnet måste vara mellan 1 och 16 tecken långt.';
$lang['Virtualmin.!error.virtualmin_username.test'] = 'Användarnamnet får inte börja med "test".';
$lang['Virtualmin.!error.virtualmin_username.format'] = 'Användarnamnet får endast innehålla bokstäver och siffror och får inte börja med en siffra.';
$lang['Virtualmin.!error.virtualmin_domain.test'] = 'Domännamnet får inte börja med "test".';
$lang['Virtualmin.!error.virtualmin_domain.format'] = 'Ange ett giltigt domännamn, t.ex. domain.com.';
$lang['Virtualmin.!error.module_row.missing'] = 'Ett internt fel har inträffat. Modulraden är inte tillgänglig.';
$lang['Virtualmin.!error.api.internal'] = 'Ett internt fel uppstod, eller så svarade inte servern på begäran.';
$lang['Virtualmin.!error.meta[template].empty'] = 'En VirtualMin Template krävs.';
$lang['Virtualmin.!error.meta[plan].empty'] = 'En VirtualMin Plan krävs.';
$lang['Virtualmin.!error.account_limit_valid'] = 'Ange en giltig kontogräns.';
$lang['Virtualmin.!error.password_valid_connection'] = 'En anslutning till servern kunde inte upprättas. Kontrollera att värdnamn, användarnamn, lösenord och port är korrekta.';
$lang['Virtualmin.!error.password_valid'] = 'Lösenordet verkar vara ogiltigt.';
$lang['Virtualmin.!error.port_valid'] = 'Porten verkar vara ogiltig.';
$lang['Virtualmin.!error.user_name_valid'] = 'Användarnamnet verkar vara ogiltigt.';
$lang['Virtualmin.!error.host_name_valid'] = 'Värdnamnet verkar vara ogiltigt.';
$lang['Virtualmin.!error.server_name_valid'] = 'Du måste ange en serveretikett.';
$lang['Virtualmin.service_field.tooltip.password'] = 'Du kan lämna lösenordet tomt för att automatiskt generera ett lösenord.';
$lang['Virtualmin.service_field.tooltip.username'] = 'Du kan lämna användarnamnet tomt för att automatiskt generera ett.';
$lang['Virtualmin.service_info.option_login'] = 'Logga in';
$lang['Virtualmin.service_info.options'] = 'Alternativ';
$lang['Virtualmin.service_info.server'] = 'Server';
$lang['Virtualmin.service_info.password'] = 'Lösenord';
$lang['Virtualmin.service_info.username'] = 'Användarnamn';
$lang['Virtualmin.tab_stats.info.maximum_mailboxes'] = 'Maximalt antal brevlådor';
$lang['Virtualmin.tab_stats.info.maximum_databases'] = 'Maximalt antal databaser';
$lang['Virtualmin.tab_stats.info.databases_count'] = 'Databas räkning';
$lang['Virtualmin.tab_stats.info.databases_size'] = 'Storlek på databas';
$lang['Virtualmin.tab_stats.info.disk_used'] = 'Använd disk';
$lang['Virtualmin.tab_stats.info_heading.value'] = 'Värde';
$lang['Virtualmin.tab_stats.info_heading.field'] = 'Fält';
$lang['Virtualmin.tab_stats.info_title'] = 'Information';
$lang['Virtualmin.tab_client_actions.field_password_submit'] = 'Uppdatera lösenord';
$lang['Virtualmin.tab_client_actions.field_virtualmin_confirm_password'] = 'Bekräfta lösenord';
$lang['Virtualmin.tab_client_actions.field_virtualmin_password'] = 'Lösenord';
$lang['Virtualmin.tab_client_actions.change_password'] = 'Ändra lösenord';
$lang['Virtualmin.service_field.confirm_password'] = 'Bekräfta lösenord';
$lang['Virtualmin.service_field.password'] = 'Lösenord';
$lang['Virtualmin.service_field.username'] = 'Användarnamn';
$lang['Virtualmin.service_field.domain'] = 'Domän';
$lang['Virtualmin.package_fields.template'] = 'Mall för VirtualMin';
$lang['Virtualmin.package_fields.plan'] = 'Plan för VirtualMin';
$lang['Virtualmin.row_meta.account_limit'] = 'Kontolimit';
$lang['Virtualmin.row_meta.use_ssl'] = 'Använd SSL när du ansluter till API:et (rekommenderas)';
$lang['Virtualmin.row_meta.port'] = 'Hamn';
$lang['Virtualmin.row_meta.password'] = 'Lösenord';
$lang['Virtualmin.row_meta.user_name'] = 'Användarnamn';
$lang['Virtualmin.row_meta.host_name'] = 'Värdnamn';
$lang['Virtualmin.row_meta.server_name'] = 'Server Etikett';
$lang['Virtualmin.edit_row.add_btn'] = 'Redigera server';
$lang['Virtualmin.edit_row.basic_title'] = 'Grundläggande inställningar';
$lang['Virtualmin.edit_row.box_title'] = 'Redigera VirtualMin Server';
$lang['Virtualmin.add_row.add_btn'] = 'Lägg till server';
$lang['Virtualmin.add_row.basic_title'] = 'Grundläggande inställningar';
$lang['Virtualmin.add_row.box_title'] = 'Lägg till VirtualMin-server';
$lang['Virtualmin.order_options.first'] = 'Första icke-fullständiga servern';
$lang['Virtualmin.manage.module_groups_no_results'] = 'Det finns inga servergrupper.';
$lang['Virtualmin.manage.module_rows_no_results'] = 'Det finns inga servrar.';
$lang['Virtualmin.manage.module_groups.confirm_delete'] = 'Är du säker på att du vill ta bort den här servergruppen?';
$lang['Virtualmin.manage.module_rows.confirm_delete'] = 'Är du säker på att du vill ta bort den här servern?';
$lang['Virtualmin.manage.module_groups.delete'] = 'Radera';
$lang['Virtualmin.manage.module_rows.delete'] = 'Radera';
$lang['Virtualmin.manage.module_groups.edit'] = 'Redigera';
$lang['Virtualmin.manage.module_rows.edit'] = 'Redigera';
$lang['Virtualmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['Virtualmin.manage.module_groups_heading.options'] = 'Alternativ';
$lang['Virtualmin.manage.module_groups_heading.servers'] = 'Antal servrar';
$lang['Virtualmin.manage.module_groups_heading.name'] = 'Gruppens namn';
$lang['Virtualmin.manage.module_rows_heading.options'] = 'Alternativ';
$lang['Virtualmin.manage.module_rows_heading.accounts'] = 'Konton';
$lang['Virtualmin.manage.module_rows_heading.port'] = 'Hamn';
$lang['Virtualmin.manage.module_rows_heading.hostname'] = 'Värdnamn';
$lang['Virtualmin.manage.module_rows_heading.name'] = 'Server Etikett';
$lang['Virtualmin.manage.module_groups_title'] = 'Servergrupper';
$lang['Virtualmin.manage.module_rows_title'] = 'Servrar';
$lang['Virtualmin.add_module_group'] = 'Lägg till servergrupp';
$lang['Virtualmin.add_module_row'] = 'Lägg till server';
$lang['Virtualmin.tab_client_actions'] = 'Åtgärder';
$lang['Virtualmin.tab_stats'] = 'Statistik';
$lang['Virtualmin.module_group'] = 'Servergrupp';
$lang['Virtualmin.module_row_plural'] = 'Servrar';
$lang['Virtualmin.module_row'] = 'Server';
$lang['Virtualmin.description'] = 'Virtualmin är en kontrollpanel för domänhosting och webbplatser, som ger möjlighet att skapa och hantera många domäner och finns i både öppen källkod och kommersiella versioner. Den är baserad på Webmin.';
$lang['Virtualmin.name'] = 'VirtuellMin';

==> blesta-5.11.4.zip: blesta/components/modules/virtualmin/language/sv_se/virtualmin.php <==
<?php
/**
 * Virtualmin
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Virtualmin.!error.virtualmin_password.valid'] = 'Lösenordet måste vara minst 8 tecken långt.';
$lang['Virtualmin.!error.virtualmin_username.length'] = 'Användarnamnet måste vara mellan 1 och 16 tecken långt.';
$lang['Virtualmin.!error.virtualmin_username.test'] = 'Användarnamnet får inte börja med "test".';
$lang['Virtualmin.!error.virtualmin_username.format'] = 'Användarnamnet får endast innehålla bokstäver och siffror och får inte börja med en siffra.';
$lang['Virtualmin.!error.virtualmin_domain.test'] = 'Domännamnet får inte börja med "test".';
$lang['Virtualmin.!error.virtualmin_domain.format'] = 'Ange ett giltigt domännamn, t.ex. domain.com.';
$lang['Virtualmin.!error.module_row.missing'] = 'Ett internt fel har inträffat. Modulraden är inte tillgänglig.';
$lang['Virtualmin.!error.api.internal'] = 'Ett internt fel uppstod, eller så svarade inte servern på begäran.';
$lang['Virtualmin.!error.meta[template].empty'] = 'En VirtualMin Template krävs.';
$lang['Virtualmin.!error.meta[plan].empty'] = 'En VirtualMin Plan krävs.';
$lang['Virtualmin.!error.account_limit_valid'] = 'Ange en giltig kontogräns.';
$lang['Virtualmin.!error.password_valid_connection'] = 'En anslutning till servern kunde inte upprättas. Kontrollera att värdnamn, användarnamn, lösenord och port är korrekta.';
$lang['Virtualmin.!error.password_valid'] = 'Lösenordet verkar vara ogiltigt.';
$lang['Virtualmin.!error.port_valid'] = 'Porten verkar vara ogiltig.';
$lang['Virtualmin.!error.user_name_valid'] = 'Användarnamnet verkar vara ogiltigt.';
$lang['Virtualmin.!error.host_name_valid'] = 'Värdnamnet verkar vara ogiltigt.';
$lang['Virtualmin.!error.server_name_valid'] = 'Du måste ange en serveretikett.';
$lang['Virtualmin.service_field.tooltip.password'] = 'Du kan lämna lösenordet tomt för att automatiskt generera ett lösenord.';
$lang['Virtualmin.service_field.tooltip.username'] = 'Du kan lämna användarnamnet tomt för att automatiskt generera ett.';
$lang['Virtualmin.service_info.option_login'] = 'Logga in';
$lang['Virtualmin.service_info.options'] = 'Alternativ';
$lang['Virtualmin.service_info.server'] = 'Server';
$lang['Virtualmin.service_info.password'] = 'Lösenord';
$lang['Virtualmin.service_info.username'] = 'Användarnamn';
$lang['Virtualmin.tab_stats.info.maximum_mailboxes'] = 'Maximalt antal brevlådor';
$lang['Virtualmin.tab_stats.info.maximum_databases'] = 'Maximalt antal databaser';
$lang['Virtualmin.tab_stats.info.databases_count'] = 'Databas räkning';
$lang['Virtualmin.tab_stats.info.databases_size'] = 'Storlek på databas';
$lang['Virtualmin.tab_stats.info.disk_used'] = 'Använd disk';
$lang['Virtualmin.tab_stats.info_heading.value'] = 'Värde';
$lang['Virtualmin.tab_stats.info_heading.field'] = 'Fält';
$lang['Virtualmin.tab_stats.info_title'] = 'Information';
$lang['Virtualmin.tab_client_actions.field_password_submit'] = 'Uppdatera lösenord';
$lang['Virtualmin.tab_client_actions.field_virtualmin_confirm_password'] = 'Bekräfta lösenord';
$lang['Virtualmin.tab_client_actions.field_virtualmin_password'] = 'Lösenord';
$lang['Virtualmin.tab_client_actions.change_password'] = 'Ändra lösenord';
$lang['Virtualmin.service_field.confirm_password'] = 'Bekräfta lösenord';
$lang['Virtualmin.service_field.password'] = 'Lösenord';
$lang['Virtualmin.service_field.username'] = 'Användarnamn';
$lang['Virtualmin.service_field.domain'] = 'Domän';
$lang['Virtualmin.package_fields.template'] = 'Mall för VirtualMin';
$lang['Virtualmin.package_fields.plan'] = 'Plan för VirtualMin';
$lang['Virtualmin.row_meta.account_limit'] = 'Kontolimit';
$lang['Virtualmin.row_meta.use_ssl'] = 'Använd SSL när du ansluter till API:et (rekommenderas)';
$lang['Virtualmin.row_meta.port'] = 'Hamn';
$lang['Virtualmin.row_meta.password'] = 'Lösenord';
$lang['Virtualmin.row_meta.user_name'] = 'Användarnamn';
$lang['Virtualmin.row_meta.host_name'] = 'Värdnamn';
$lang['Virtualmin.row_meta.server_name'] = 'Server Etikett';
$lang['Virtualmin.edit_row.add_btn'] = 'Redigera server';
$lang['Virtualmin.edit_row.basic_title'] = 'Grundläggande inställningar';
$lang['Virtualmin.edit_row.box_title'] = 'Redigera VirtualMin Server';
$lang['Virtualmin.add_row.add_btn'] = 'Lägg till server';
$lang['Virtualmin.add_row.basic_title'] = 'Grundläggande inställningar';
$lang['Virtualmin.add_row.box_title'] = 'Lägg till VirtualMin-server';
$lang['Virtualmin.order_options.first'] = 'Första icke-fullständiga servern';
$lang['Virtualmin.manage.module_groups_no_results'] = 'Det finns inga servergrupper.';
$lang['Virtualmin.manage.module_rows_no_results'] = 'Det finns inga servrar.';
$lang['Virtualmin.manage.module_groups.confirm_delete'] = 'Är du säker på att du vill ta bort den här servergruppen?';
$lang['Virtualmin.manage.module_rows.confirm_delete'] = 'Är du säker på att du vill ta bort den här servern?';
$lang['Virtualmin.manage.module_groups.delete'] = 'Radera';
$lang['Virtualmin.manage.module_rows.delete'] = 'Radera';
$lang['Virtualmin.manage.module_groups.edit'] = 'Redigera';
$lang['Virtualmin.manage.module_rows.edit'] = 'Redigera';
$lang['Virtualmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['Virtualmin.manage.module_groups_heading.options'] = 'Alternativ';
$lang['Virtualmin.manage.module_groups_heading.servers'] = 'Antal servrar';
$lang['Virtualmin.manage.module_groups_heading.name'] = 'Gruppens namn';
$lang['Virtualmin.manage.module_rows_heading.options'] = 'Alternativ';
$lang['Virtualmin.manage.module_rows_heading.accounts'] = 'Konton';
$lang['Virtualmin.manage.module_rows_heading.port'] = 'Hamn';
$lang['Virtualmin.manage.module_rows_heading.hostname'] = 'Värdnamn';
$lang['Virtualmin.manage.module_rows_heading.name'] = 'Server Etikett';
$lang['Virtualmin.manage.module_groups_title'] = 'Servergrupper';
$lang['Virtualmin.manage.module_rows_title'] = 'Servrar';
$lang['Virtualmin.add_module_group'] = 'Lägg till servergrupp';
$lang['Virtualmin.add_module_row'] = 'Lägg till server';
$lang['Virtualmin.tab_client_actions'] = 'Åtgärder';
$lang['Virtualmin.tab_stats'] = 'Statistik';
$lang['Virtualmin.module_group'] = 'Servergrupp';
$lang['Virtualmin.module_row_plural'] = 'Servrar';
$lang['Virtualmin.module_row'] = 'Server';
$lang['Virtualmin.description'] = 'Virtualmin är en kontrollpanel för domänhosting och webbplatser, som ger möjlighet att skapa och hantera många domäner och finns i både öppen källkod och kommersiella versioner. Den är baserad på Webmin.';
$lang['Virtualmin.name'] = 'VirtuellMin';
$lang['Virtualmin.!error.meta[domains_list].valid'] = 'En eller flera paketdomäner är ogiltiga.';
$lang['Virtualmin.package_fields.tooltip.domains_list'] = 'Ange en CSV-lista över domäner som kommer att vara tillgängliga för att tillhandahålla underdomäner för, t.ex. "domain1.com,domain2.com,domain3.com"';
$lang['Virtualmin.package_fields.domains_list'] = 'Lista över tillgängliga domäner';
$lang['Virtualmin.package_fields.sub_domains_disable'] = 'Avaktivera';
$lang['Virtualmin.package_fields.sub_domains_enable'] = 'Aktivera';
$lang['Virtualmin.package_fields.sub_domains'] = 'Aktivera försäljning av underdomäner';
